==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/pt/pub.php <==
<?php
regGS("Publication List", "Lista de Publicações");
regGS("Go To Issues", "Ir para edições");
regGS("Name<BR><SMALL>(click to see issues)</SMALL>", "Nome (Carregue para ver Edições)");
regGS("Delete publication $1", "Apagar Publicação");
regGS("No publications.", "Não existem Publicações");
regGS("Default Site Alias", "Alias do Site");
regGS("URL Type", "Tipo de Endereço URL");
regGS("Country<BR><SMALL>(click to edit)</SMALL>", "País (Carregue para Alterar)");
regGS("Delete alias $1", "Apagar $1");
regGS("Configure publication", "Configurar Publicação");
regGS("You do not have the right to edit publication information.", "Não tem permissão para Alterar Detalhes de Publicação");
regGS("General attributes", "Definições Gerais");
regGS("Subscriptions defaults", "Definições de Assinaturas");
regGS("Countries defaults", "Definições de Paises");
regGS("Changing publication information", "Alterando Detalhes de Publicação");
regGS("You do not have the right to change publication information.", "Não tem permissão para Alterar Detalhes de Publicação");
regGS("The publication information could not be updated.", "Os detalhes de Publicação não podem ser alterados");
regGS("Please check if another publication with the same name or the same site name does not already exist.", "Verifique se já não existem uma Publicação com o mesmo nome ou com o mesmo endereço URL");
regGS("You do not have the right to delete publications.", "Não tem permissão para Apagar Publicações");
regGS("Are you sure you want to delete the publication $1?", "Confirma o apagamento da Publicação $1?");
regGS("Deleting publication", "Apagando Publicação");
regGS("There are $1 subscription(s) left.", "Existe(m) ainda $1 Assinatura(s)");
regGS("The publication $1 could not be deleted.", "A Publicação $1 não pode ser Apagada");
regGS("Adding new publication", "Criar Publicação");
regGS("The publication could not be added.", "A Publicação não pode ser Criada");
regGS("Select the publication", "Escolha a Publicação");
regGS("Add new country default subscription time", "Adicionar tempo de Assinatura para Pais");
regGS("You do not have the right to manage publications.", "Não tem permissões para gerir Publicações");
regGS("Please check if another entry with the same country code exists already.", "Verifica se ja não existe registado um pais com o codigo que pretende.");
regGS("Adding new country default subscription time", "Adicionando novo tempo de Assinatura");
regGS("You must select a country.", "Tem de escolher um País");
regGS("The default subscription time for country $1 could not be added.", "Não pode ser adiciondo um tempo de Assinatura para $1 ");
regGS("Change subscription default time", "Alterar tempo de Assinatura");
regGS("Default subscription time for $1 changed", "Tempo de Assinatura para $1 foi alterado");
regGS("Are you sure you want to delete the subscription default time for $1?", "Confirma o apagamento do tempo de Assinatura");
regGS("Subscription default time for $1 deleted", "Tempo de Assinatura para $1 foi apagado");
regGS("Name<BR><SMALL>(click to select the publication)</SMALL>", "Nome (Carregue para selecionar Publicação)");
regGS("Add new alias", "Adicionar novo Alias");
regGS("Alias (click to edit)", "Alias (carregue para editar)");
regGS("Edit aliases", "Editar Alias");
regGS("Publication Aliases", "Alias de Publicações");
regGS("Adding new alias", "Adicionar Alias");
regGS("The site alias $1 has been added to publication $2.", "O Alias $1 foi eliminado da publicação $2.");
regGS("The site alias $1 could not be added.", "O Alias $1 não pode ser adicionado.");
regGS("Another alias with the same name exists already.", "Ja existe um alias idêntico.");
regGS("Edit alias", "Editar Alias.");
regGS("Editing alias", "Editando Alias");
regGS("The site alias for publication $1 has been modified to $2.", "O Alias para a publicação $1 foi modificado para $2.");
regGS("The site alias $1 could not be modified.", "O Alias $1 não pode ser modificado.");
regGS("Are you sure you want to delete the alias $1?", "Confirma eliminação do alias $1?");
regGS("Deleting alias", "Eliminando Alias");
regGS("The alias $1 could not be deleted.", "O Alias $1 não pode ser eliminado.");
regGS("The alias $1 has been deleted from publication $2.", "O Alias $1 foi eliminado da publicação $2.");
regGS("$1 is the default publication alias, it can not be deleted.", "$1 é o alias principal da publicação e como tal não pode ser eliminado.");
regGS("You do not have the right to add publications.", "Nao tem permissões para adicionar publicações.");
regGS("There are $1 issue(s) left.", "Existe(m) ainda $1 Edição(ões).");
regGS("Change publication information", "Alterar detalhes da Publicação");
?>

==> campsite-2.6.7_5.tbz: campsite/www-common/html/priv/lang/pt/pub.php <==
<?php 
regGS("Use CAPTCHA to prevent spam?", "");
regGS("Public allowed to comment?", "");
regGS("Enable spam blocking?", "");
regGS("The subscription settings for '$1' could not be added.", "");
regGS("The publication name you specified conflicts with publication '$1'.", "");
regGS("The publication alias you specified conflicts with publication '$1'.", "");
regGS("Subscription defaults", "");
regGS("Subscription Settings by Country", "");
regGS("Set subscription settings for a country", "");
regGS("Set subscription settings by country", "");
regGS("Default time periods:", "");
regGS("Country subscription settings updated.", "");
regGS("Country subscription settings deleted.", "");
regGS("Change country subscription settings", "");
regGS("Are you sure you want to delete the subscription settings for $1?", "");
regGS("Publication updated", "");
regGS("Subscriber comments moderated?", "");
regGS("Public comments moderated?", "");
regGS("Comments enabled?", "");
regGS("Comments enabled", "");
regGS("Article comments default to enabled?", "");
regGS("trial subscription", "Assinatura para demonstração");
regGS("paid subscription", "Assinatura paga");
regGS("time units", "unidade de tempo");
regGS("one language", "um idioma");
regGS("all languages", "todos os idiomas");
regGS("Trial subscriptions", "Assinatura para demonstração");
regGS("Time unit cost per one section", "Custo por unidade de tempo por secção");
regGS("Paid subscriptions", "Assinaturas pagas");
regGS("Default time period", "Periodo de tempo por defeito");
regGS("Go To Issues", "Ir para edições");
regGS("Name<BR><SMALL>(click to see issues)</SMALL>", "Nome (Carregue para ver Edições)");
regGS("Delete publication $1", "Apagar Publicação");
regGS("No publications.", "Não existem Publicações");
regGS("Default Site Alias", "Alias do Site");
regGS("URL Type", "Tipo de Endereço URL");
regGS("Country<BR><SMALL>(click to edit)</SMALL>", "País (Carregue para Alterar)");
regGS("Delete alias $1", "Apagar $1");
regGS("Configure publication", "Configurar Publicação");
regGS("You do not have the right to edit publication information.", "Não tem permissão para Alterar Detalhes de Publicação");
regGS("General attributes", "Definições Gerais");
regGS("You do not have the right to change publication information.", "Não tem permissão para Alterar Detalhes de Publicação");
regGS("The publication information could not be updated.", "Os detalhes de Publicação não podem ser alterados");
regGS("You do not have the right to delete publications.", "Não tem permissão para Apagar Publicações");
regGS("Are you sure you want to delete the publication $1?", "Confirma o apagamento da Publicação $1?");
regGS("Deleting publication", "Apagando Publicação");
regGS("There are $1 subscription(s) left.", "Existe(m) ainda $1 Assinatura(s)");
regGS("The publication $1 could not be deleted.", "A Publicação $1 não pode ser Apagada");
regGS("The publication could not be added.", "A Publicação não pode ser Criada");
regGS("You do not have the right to manage publications.", "Não tem permissões para gerir Publicações");
regGS("You must select a country.", "Tem de escolher um País");
regGS("Default subscription time for $1 changed", "Tempo de Assinatura para $1 foi alterado");
regGS("Subscription default time for $1 deleted", "Tempo de Assinatura para $1 foi apagado");
regGS("Add new alias", "Adicionar novo Alias");
regGS("Alias (click to edit)", "Alias (carregue para editar)");
regGS("Edit aliases", "Editar Alias");
regGS("Publication Aliases", "Alias de Publicações");
regGS("Adding new alias", "Adicionar Alias");
regGS("The site alias $1 has been added to publication $2.", "O Alias $1 foi eliminado da publicação $2.");
regGS("The site alias $1 could not be added.", "O Alias $1 não pode ser adicionado.");
regGS("Another alias with the same name exists already.", "Ja existe um alias idêntico.");
regGS("Edit alias", "Editar Alias.");
regGS("Editing alias", "Editando Alias");
regGS("The site alias for publication $1 has been modified to $2.", "O Alias para a publicação $1 foi modificado para $2.");
regGS("The site alias $1 could not be modified.", "O Alias $1 não pode ser modificado.");
regGS("Are you sure you want to delete the alias $1?", "Confirma eliminação do alias $1?");
regGS("Deleting alias", "Eliminando Alias");
regGS("The alias $1 could not be deleted.", "O Alias $1 não pode ser eliminado.");
regGS("The alias $1 has been deleted from publication $2.", "O Alias $1 foi eliminado da publicação $2.");
regGS("$1 is the default publication alias, it can not be deleted.", "$1 é o alias principal da publicação e como tal não pode ser eliminado.");
regGS("You do not have the right to add publications.", "Nao tem permissões para adicionar publicações.");
regGS("There are $1 issue(s) left.", "Existe(m) ainda $1 Edição(ões).");
regGS("Change publication information", "Alterar detalhes da Publicação");
regGS("Time Unit", "Unidade de Tempo");
regGS("Currency", "Moeda");
regGS("Edit languages", "Editar Idiomas");
?>
